@@ -6,7 +6,7 @@ use 5.008003;
 use FormValidator::Lite::Constraint;
 use Moose::Util::TypeConstraints ();
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 my $get_constraint = Moose::Util::TypeConstraints->can('find_type_constraint');
 
@@ -47,7 +47,7 @@ FormValidator::Lite::Constraint::Moose - Use Moose's type constraints.
   use FormValidator::Lite;
   use Moose::Util::TypeConstraints;
 
-  enum 'HttpMethod' => qw(GET HEAD POST PUT DELETE); #you must load before load 'FormValidator::Lite->load_constraints(qw/Moose/)'
+  enum 'HttpMethod' => [qw(GET HEAD POST PUT DELETE)]; #you must load before load 'FormValidator::Lite->load_constraints(qw/Moose/)'
 
   FormValidator::Lite->load_constraints(qw/Moose/);
 
